# Unreleased

# 0.0.3

- Add `--disable` for turning off specific codes
- Various minor speed improvements, resulting in ~5% faster runs on large
  codebases
- Invert verbosity control by removing `-q/--quiet` and adding `-v/--verbose`.
  Verbose output is now opt-in, not opt-out.

# 0.0.2

- Add pre-commit-hooks config, allowing use with pre-commit

# 0.0.1

- Initial release
